@@ -10,7 +10,7 @@ use Perinci::Exporter;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-05-08'; # DATE
 our $DIST = 'App-ImageMagickUtils'; # DIST
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 our %SPEC;
 
@@ -205,7 +205,7 @@ sub downsize_image {
         }
 
         if ($skip_downsized) {
-            if ($file =~ /\.(?:\d+-)?q(?:\d{1,3})\.\w+\z/) {
+            if ($file =~ /\.(?:\d+p?-)?q(?:\d{1,3})\.\w+\z/) {
                 log_info "Filename '%s' looks like it's already downsized, skip downsizing due to --skip-downsized option is in effect", $file;
                 next FILE;
             }
@@ -392,7 +392,7 @@ App::ImageMagickUtils - Utilities related to ImageMagick
 
 =head1 VERSION
 
-This document describes version 0.016 of App::ImageMagickUtils (from Perl distribution App-ImageMagickUtils), released on 2022-05-08.
+This document describes version 0.017 of App::ImageMagickUtils (from Perl distribution App-ImageMagickUtils), released on 2022-05-08.
 
 =head1 DESCRIPTION
 
